( cd usr/bin ; rm -rf gdb )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/gdb gdb )
( cd usr/man/preformat/cat1 ; rm -rf gdb.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/gdb.1.gz gdb.1.gz )
( cd usr/info ; rm -rf gdb.info.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gdb.info.gz gdb.info.gz )
( cd usr/info ; rm -rf gdb.info-1.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gdb.info-1.gz gdb.info-1.gz )
( cd usr/info ; rm -rf gdb.info-2.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gdb.info-2.gz gdb.info-2.gz )
( cd usr/info ; rm -rf gdb.info-3.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gdb.info-3.gz gdb.info-3.gz )
( cd usr/info ; rm -rf gdb.info-4.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gdb.info-4.gz gdb.info-4.gz )
( cd usr/info ; rm -rf gdb.info-5.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gdb.info-5.gz gdb.info-5.gz )
( cd usr/info ; rm -rf gdb.info-6.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gdb.info-6.gz gdb.info-6.gz )
( cd usr/info ; rm -rf gdb.info-7.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gdb.info-7.gz gdb.info-7.gz )
( cd usr/info ; rm -rf gdb.info-8.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gdb.info-8.gz gdb.info-8.gz )
( cd usr/doc/gdb ; rm -rf NEWS )
( cd usr/doc/gdb ; ln -sf /cdrom/live/usr/doc/gdb/NEWS NEWS )
( cd usr/doc/gdb ; rm -rf Projects )
( cd usr/doc/gdb ; ln -sf /cdrom/live/usr/doc/gdb/Projects Projects )
( cd usr/doc/gdb ; rm -rf README )
( cd usr/doc/gdb ; ln -sf /cdrom/live/usr/doc/gdb/README README )
